package com.xy.service;

import com.xy.dto.AlgorithmGoodsDto;
import com.xy.entity.Algorithm;
import com.xy.entity.AlgorithmGoods;
import com.xy.mapper.AlgorithmGoodsMapper;
import com.xy.utils.*;
import icu.mhb.mybatisplus.plugln.base.service.impl.JoinServiceImpl;
import icu.mhb.mybatisplus.plugln.core.JoinLambdaWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;


/**
 * <p>
 * 算法平台商品库 服务实现类
 * </p>
 *
 * @author hechunping
 * @since 2023/1/13
 */
@Service
@Api(tags = "算法平台商品库")
public class AlgorithmGoodsServiceImpl extends JoinServiceImpl<AlgorithmGoodsMapper, AlgorithmGoods> implements AlgorithmGoodsService {
    @ApiOperation("分页查询")
    @Override
    public R<PageBean<AlgorithmGoodsDto.Vo>> page(@RequestBody AlgorithmGoodsDto.Page page) {
        PageBean pageBean = page.getPage();
        JoinLambdaWrapper<AlgorithmGoods> lambdaWrapper = new MybatisPlusQuery().eqWrapper(page, AlgorithmGoods.class)
                .ge(AlgorithmGoods::getCreateTime, page.getCreateTimeStart())
                .le(AlgorithmGoods::getCreateTime, page.getCreateTimeEnd())
                .like(AlgorithmGoods::getSkuName)
                .buildJoin()
                .leftJoin(Algorithm.class, Algorithm::getId, AlgorithmGoods::getAlgorithmId)
                .selectAs(Algorithm::getName, LambdaUtils.getProperty(AlgorithmGoodsDto.Vo::getAlgorithmName))
                .end();
        return R.ok(joinPage(PlusBeans.toIPage(pageBean), lambdaWrapper, AlgorithmGoodsDto.Vo.class));
    }

    @ApiOperation("新增")
    @Override
    public R save(@RequestBody @Validated AlgorithmGoodsDto.Save save) {
        AlgorithmGoods saveInfo = PlusBeans.copy(AlgorithmGoods.class, save);
        saveInfo.createUserTime(AuthorizeUtils.getLoginId(Long.class)).createId();
        save(saveInfo);
        return R.ok();
    }

    @ApiOperation("修改")
    @Override
    public R update(@RequestBody @Validated AlgorithmGoodsDto.Update update) {
        AlgorithmGoods updateInfo = PlusBeans.copy(AlgorithmGoods.class, update);
        updateInfo.updateUserTime(AuthorizeUtils.getLoginId(Long.class));
        updateById(updateInfo);
        return R.ok();
    }
}
